//
// elmo.h
//
// Emic 2-to-Elmo
//
// This file contains code for the Microchip PIC12F675 for CCS PCM
//

#ifndef __INC_ELMO_H__
#define __INC_ELMO_H__

#include <12F675.h>

// port definitions
#define SIN  		PIN_A0
#define SOUT    	PIN_A1
#define SW_PLAY 	PIN_A2
#define SW_SHUFFLE	PIN_A4
#define SW_STOP		PIN_A5

#use delay(clock=4000000, restart_wdt)
#use rs232(baud=9600, bits=8, parity=N, stop=1, xmit=SIN, rcv=SOUT, FORCE_SW)

// Configuration Bits:
// Oscillator = Internal RC, I/O on GP4/GP5
// Watchdog Timer (WDT) = ENABLED
// Power-Up Timer = ENABLED
// Master Clear = ENABLED
// Brown-out Detect = ENABLED
// Code Protect = DISABLED
// Data Code Protect = DISABLED
#fuses INTRC_IO, WDT, PUT, MCLR, BROWNOUT, NOPROTECT, NOCPD

#define DB_TIME		250		// time of debounce (in ms)

typedef enum // define the modes for the state machine
{
   IDLE, 
   PLAYING
} state_type;


// function prototypes
BOOLEAN emic2_check(void);
void emic2_init(void);
void hardware_init(void);

#endif
